@@ -4,6 +4,9 @@ Beran <-
     spa <- NULL
     len <- length(time)
     if (missing(delta)) delta <- rep(1, len)
-    res <- .C( "SurvBeranKernel", as.double(time), as.integer(status), as.double(covariate), as.integer(delta), as.integer(len), as.double(y), as.double(x), as.double(bw), as.character(kernel), p = as.double(1))$p
+    res <- .C( "SurvBeranKernel", as.double(time), as.integer(status),
+               as.double(covariate), as.integer(delta), as.integer(len),
+               as.double(y), as.double(x), as.double(bw),
+               as.character(kernel), p = as.double(1))$p
     if (lower.tail == TRUE) res <- 1 - res
     return(res)}
